"""Auto-generated file, do not edit by hand. 84 metadata"""
from ..phonemetadata import NumberFormat

PHONE_ALT_FORMAT_84 = [NumberFormat(pattern='(9\\d{2})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['9']), NumberFormat(pattern='([48])(\\d{2})(\\d{3})(\\d{3})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['[48]'])]
